earlyster_probability
=====================

.. image:: https://img.shields.io/pypi/v/earlyster_probability.svg
    :target: https://pypi.python.org/pypi/earlyster_probability
    :alt: Latest PyPI version


Binomial and Gaussian Distribution Probability Library

Usage
-----

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------

Authors
-------

`earlyster_probability` was written by `Justin Early <earlyster@gmail.com>`_.
